@@ -1,3 +1,4 @@
+// -*- c++ -*-
 /*
  * Copyright 2002, The libsigc++ Development Team
  *
@@ -22,7 +23,7 @@ using namespace std;
 
 namespace sigc {
 
-connection::connection() noexcept
+connection::connection()
 : slot_(nullptr)
 {}
 
@@ -53,27 +54,27 @@ connection::~connection()
     slot_->remove_destroy_notify_callback(this);
 }
 
-bool connection::empty() const noexcept
+bool connection::empty() const
 {
   return (!slot_ || slot_->empty());
 }
 
-bool connection::connected() const noexcept
+bool connection::connected() const
 {
   return !empty();
 }
 
-bool connection::blocked() const noexcept
+bool connection::blocked() const
 {
   return (slot_ ? slot_->blocked() : false);
 }
 
-bool connection::block(bool should_block) noexcept
+bool connection::block(bool should_block)
 {
   return (slot_ ? slot_->block(should_block) : false);
 }
 
-bool connection::unblock() noexcept
+bool connection::unblock()
 {
   return (slot_ ? slot_->unblock() : false);
 }
@@ -84,7 +85,7 @@ void connection::disconnect()
     slot_->disconnect(); // This notifies slot_'s parent.
 } 
 
-connection::operator bool() noexcept
+connection::operator bool()
 {
   return !empty();
 }
@@ -104,7 +105,7 @@ void* connection::notify(void* data)
 {
   auto self = reinterpret_cast<connection*>(data);
   self->slot_ = nullptr;
-  return nullptr;
+  return 0;
 }
 
 } /* namespace sigc */
