@@ -167,6 +167,13 @@ signal_base::signal_base(const signal_base& src)
   impl_->reference();
 }
 
+signal_base::signal_base(signal_base&& src) noexcept
+: trackable(std::move(src)),
+  impl_(std::move(src.impl_))
+{
+  src.impl_ = nullptr;
+}
+
 signal_base::~signal_base()
 {
   if (impl_)
@@ -223,7 +230,7 @@ signal_base::iterator_type signal_base::erase(iterator_type i)
   return impl()->erase(i);
 }
 
-signal_base& signal_base::operator = (const signal_base& src)
+signal_base& signal_base::operator=(const signal_base& src)
 {
   if (src.impl_ == impl_) return *this;
 
@@ -241,6 +248,16 @@ signal_base& signal_base::operator = (const signal_base& src)
   return *this;
 }
 
+signal_base& signal_base::operator=(signal_base&& src) noexcept
+{
+  trackable::operator=(std::move(src));
+  impl_ = std::move(src.impl_);
+
+  src.impl_ = nullptr;
+
+  return *this;
+}
+
 internal::signal_impl* signal_base::impl() const
 {
   if (!impl_) {
