@@ -38,6 +38,12 @@ trackable::trackable(const trackable& /*src*/)
 : callback_list_(nullptr)
 {}
 
+trackable::trackable(trackable&& src) noexcept
+: callback_list_(std::move(src.callback_list_))
+{
+  src.callback_list_ = nullptr;
+}
+
 trackable& trackable::operator=(const trackable& src)
 {
   if(this != &src)
@@ -46,6 +52,18 @@ trackable& trackable::operator=(const trackable& src)
   return *this;
 }
 
+trackable& trackable::operator=(trackable&& src) noexcept
+{
+  if(this != &src)
+    notify_callbacks(); //Make sure that we have finished with existing stuff before replacing it.
+
+  callback_list_ = std::move(src.callback_list_);
+
+  src.callback_list_ = nullptr;
+
+  return *this;
+}
+
 trackable::~trackable()
 {
   notify_callbacks();
@@ -81,6 +99,25 @@ internal::trackable_callback_list* trackable::callback_list() const
 namespace internal
 {
 
+trackable_callback_list::trackable_callback_list(trackable_callback_list&& src) noexcept
+: callbacks_(std::move(src.callbacks_)),
+  clearing_(std::move(src.clearing_))
+{
+  src.callbacks_.clear();
+  src.clearing_ = false;
+}
+
+trackable_callback_list& trackable_callback_list::operator=(trackable_callback_list&& src) noexcept
+{
+  callbacks_ = std::move(src.callbacks_);
+  clearing_ = std::move(src.clearing_);
+
+  src.callbacks_.clear();
+  src.clearing_ = false;
+
+  return *this;
+}
+
 trackable_callback_list::~trackable_callback_list()
 {
   clearing_ = true;
